import subprocess
from github import Github
import click
import argparse
from gitfun import GitFun as gf

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
@click.group(context_settings=CONTEXT_SETTINGS)
def cli():
    pass




@cli.command()
def status():
    click.echo(gf.status())

@cli.command()
@click.option('-url', type=str, help='Paste your link of the repo',required=False)
@click.option('-m',type=str,help = "Commit message ")
@click.option('-b',type=str, help ="Branch name for checkout")

def pushbranch(m,b,**url):
    click.echo(gf.push_branch(m,b,**url))

@cli.command()
def remote():
    click.echo(gf.remote())

if __name__ == '__main__':
    cli()


import subprocess
from github import Github





def status():
    return subprocess.getoutput("git status")


def push_branch(m:str,b:str,**url:str) -> str:
    try:    
        cmd_remote = "git remote add origin {0}".format(url)
        cmd_branch = "git checkout {} ".format(b)
        cmd_message = 'git commit -m "{}"'.format(m)
        cmd_push = "git push origin {}".format(b)
        if(b=="master" or b=="main" and m=="initial commit"):
            subprocess.getoutput('git init')
            subprocess.getoutput("git add .")  
            subprocess.getoutput(cmd_remote)
            print(cmd_remote)
            subprocess.getoutput(cmd_branch)
            print(cmd_message)
            subprocess.getoutput(cmd_message)
            result = subprocess.getoutput(cmd_push)
            return  result
        else:
            subprocess.getoutput(cmd_branch)     
            subprocess.getoutput("git add -u")
            subprocess.getoutput(cmd_message)
            result = subprocess.getoutput(cmd_push) 
            return  result
    except Exception as ex:
        print(ex)



def remote():
    return subprocess.getoutput("git remote -v")


from setuptools import setup, find_packages
from os import path


# this_directory = path.abspath(path.dirname(__file__))
# with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
#     long_description = f.read()

setup(
    name = 'gitfun',
    version = '0.0.9.9',
    author = 'Shreeda Bhat',
    author_email = 'shreeda@astaqc.com',
    url = "https://github.com/memetics19/gitfun.git",
    license = 'MIT',
    description = 'Make Git simplified for lazy developers ',
    install_requires=[
    'bleach==3.3.0',
    'certifi==2020.12.5',
    'cffi==1.14.5',
    'chardet==4.0.0',
    'click==7.1.2',
    'colorama==0.4.4', 
    'Deprecated==1.2.12',
    'docutils==0.17.1',
    'idna==2.10' ,
    'importlib-metadata==4.0.1',
    'keyring==23.0.1',
    'packaging==20.9',
    'pkginfo==1.7.0' ,
    'pycparser==2.20',
    'PyGithub==1.55',
    'Pygments==2.8.1',
    'PyJWT==2.1.0',
    'PyNaCl==1.4.0',
    'pyparsing==2.4.7',
    'readme-renderer==29.0',
    'requests==2.25.1',
    'requests-toolbelt==0.9.1',
    'rfc3986==1.4.0',
    'six==1.15.0',
    'tqdm==4.60.0',
    'twine==3.4.1' ,  
    'urllib3==1.26.5',
    'webencodings==0.5.1',
    'wrapt==1.12.1',
    'zipp==3.4.1'
    ],
    long_description_content_type='text/markdown',
    py_modules = ['cli_main', 'gitfun'],
    packages = find_packages(),
    python_requires='>=3.7',
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    entry_points = '''
        [console_scripts]
        fun=cli_main:cli
    '''
)
